@@ -17,6 +17,9 @@
  */
 
 #define ICAL_GET_FIELD(LOWER_NAME, UPPER_NAME, TYPE, DEFAULT) \
+  TYPE                                                        \
+  ical_util_get_##LOWER_NAME (icalcomponent *comp);           \
+                                                              \
   TYPE                                                 \
   ical_util_get_##LOWER_NAME (icalcomponent *comp)             \
   {                                                           \
@@ -33,6 +36,7 @@
     }                                                                   \
   }
 
+#include "config.h"
 #include "ical-util.h"
 
 #include <glib.h>
