@@ -40,6 +40,6 @@ ICAL_GET_FIELD(url, URL, const char*, NULL);
 ICAL_GET_FIELD(categories, CATEGORIES, const char*, NULL);
 
 /* TODO: split this out */
-char * ical_util_get_human_date (GDate *due);
+char * ical_util_get_human_due_date (GDate *due);
 
 #endif /* _ICAL_UTIL_H */
