@@ -20,7 +20,7 @@
 #define _KOTO_FIELD_EDITOR_FACTORY
 
 #include <libical/icalproperty.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include "koto-task.h"
 
 G_BEGIN_DECLS
