@@ -114,6 +114,9 @@ koto_group_combo_init (KotoGroupCombo *self)
   GtkCellRenderer *renderer;
 
   renderer = gtk_cell_renderer_text_new ();
+  g_object_set (renderer,
+                "ellipsize", PANGO_ELLIPSIZE_END,
+                NULL);
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (self), renderer, TRUE);
   gtk_cell_layout_set_cell_data_func  (GTK_CELL_LAYOUT (self), renderer,
                                        group_name_data_func, NULL, NULL);
