@@ -45,7 +45,7 @@ get_name (KotoGroup *group)
   case KOTO_META_GROUP_NONE:
     return _("None");
   case KOTO_META_GROUP_NEW:
-    return _("New Group...");
+    return _("New Category...");
   }
 
   return NULL;
