@@ -19,8 +19,11 @@
 #ifndef _KOTO_PLATFORM
 #define _KOTO_PLATFORM
 
+#include "koto-task.h"
+
 G_BEGIN_DECLS
 
 void koto_platform_open_url (const char *url);
+void koto_platform_edit_task (KotoTask *task);
 
 #endif /* _KOTO_PLATFORM */
