@@ -19,7 +19,7 @@
 #ifndef _KOTO_TASK_STORE
 #define _KOTO_TASK_STORE
 
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <libecal/e-cal-view.h>
 #include "koto-task.h"
 #include "koto-undo-manager.h"
