@@ -308,29 +308,31 @@ static void
 koto_task_view_style_set (GtkWidget *widget, GtkStyle *previous)
 {
   KotoTaskViewPrivate *priv;
+  GtkStyle *style;
 
   g_assert (KOTO_IS_TASK_VIEW (widget));
 
   priv = GET_PRIVATE (widget);
 
+  style = gtk_widget_get_style (widget);
 #if HAVE_DECL_GTK_STYLE_LOOKUP_COLOR
-  if (!gtk_style_lookup_color (widget->style, "priority-low", &priv->colour_low)) {
-    priv->colour_low = widget->style->text[GTK_STATE_INSENSITIVE];
+  if (!gtk_style_lookup_color (style, "priority-low", &priv->colour_low)) {
+    priv->colour_low = style->text[GTK_STATE_INSENSITIVE];
   }
-  if (!gtk_style_lookup_color (widget->style, "priority-normal", &priv->colour_normal)) {
-    priv->colour_normal = widget->style->text[GTK_STATE_NORMAL];
+  if (!gtk_style_lookup_color (style, "priority-normal", &priv->colour_normal)) {
+    priv->colour_normal = style->text[GTK_STATE_NORMAL];
   }
-  if (!gtk_style_lookup_color (widget->style, "priority-high", &priv->colour_high)) {
-    priv->colour_high = widget->style->text[GTK_STATE_NORMAL];
+  if (!gtk_style_lookup_color (style, "priority-high", &priv->colour_high)) {
+    priv->colour_high = style->text[GTK_STATE_NORMAL];
   }
-  if (!gtk_style_lookup_color (widget->style, "priority-done", &priv->colour_done)) {
-    priv->colour_done = widget->style->text[GTK_STATE_INSENSITIVE];
+  if (!gtk_style_lookup_color (style, "priority-done", &priv->colour_done)) {
+    priv->colour_done = style->text[GTK_STATE_INSENSITIVE];
   }
 #else
-  priv->colour_low = widget->style->text[GTK_STATE_INSENSITIVE];
-  priv->colour_normal = widget->style->text[GTK_STATE_NORMAL];
-  priv->colour_high = widget->style->text[GTK_STATE_NORMAL];
-  priv->colour_done = widget->style->text[GTK_STATE_INSENSITIVE];
+  priv->colour_low = style->text[GTK_STATE_INSENSITIVE];
+  priv->colour_normal = style->text[GTK_STATE_NORMAL];
+  priv->colour_high = style->text[GTK_STATE_NORMAL];
+  priv->colour_done = style->text[GTK_STATE_INSENSITIVE];
 #endif
 
   GTK_WIDGET_CLASS (koto_task_view_parent_class)->style_set (widget, previous);
