@@ -19,8 +19,7 @@
 #ifndef _KOTO_UTILS
 #define _KOTO_UTILS
 
-#include <gtk/gtkwindow.h>
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
