@@ -16,6 +16,6 @@
  * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 void window_bind_state (GtkWindow *window, const char *name);
